@@ -11,8 +11,8 @@ from mxcubeweb.core.util.networkutils import RateLimited
 
 resource_handler_config = ResourceHandlerConfigModel(
     url_prefix="/mxcube/api/v0.1/motor_test",
-    commands=["set_value", "get_value", "stop"],
-    attributes=["data"],
+    commands=["set_value", "stop"],
+    attributes=["data", "get_value"],
 )
 
 
