@@ -25,7 +25,6 @@ class AppSettingsModel(BaseModel):
             "be dis-activated to not clash with i.e workflow mesh,"
         ),
     )
-
     enable_2d_points: bool = Field(
         True,
         description=(
@@ -33,6 +32,10 @@ class AppSettingsModel(BaseModel):
             " (none centred positions)"
         ),
     )
+    click_centring_num_clicks: int = Field(
+        3,
+        description="Number of clicks used for the manual click centring",
+    )
 
     class Config:
         extra: "forbid"  # noqa: F821
