@@ -133,11 +133,12 @@ def init_route(app, server, url_prefix):  # noqa: C901
     @server.restrict
     def rasettings():
         """ """
+        operator = app.usermanager.get_operator()
         data = {
             "observers": [_u.todict() for _u in app.usermanager.get_observers()],
             "allowRemote": app.ALLOW_REMOTE,
             "timeoutGivesControl": app.TIMEOUT_GIVES_CONTROL,
-            "operator": app.usermanager.get_operator().todict(),
+            "operator": operator.todict() if operator else None,
         }
 
         return jsonify(data=data)
